pub fn exploration_stats() -> Option<ExplorationStats>Expand description
Get a snapshot of the current exploration statistics.
Returns None if the stats pointer is null (exploration not initialized).
pub fn exploration_stats() -> Option<ExplorationStats>Get a snapshot of the current exploration statistics.
Returns None if the stats pointer is null (exploration not initialized).